intelmq.bots.collectors.rt package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.collectors.rt package

## Submodules

## intelmq.bots.collectors.rt.collector_rt module

intelmq.bots.collectors.rt.collector_rt.BOT

  alias of `intelmq.bots.collectors.rt.collector_rt.RTCollectorBot`

class intelmq.bots.collectors.rt.collector_rt.RTCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`, `intelmq.lib.mixins.http.HttpMixin`

  Fetches attachments and URLs from an Request Tracker ticketing server

  PARAMETER_MAPPING = {'search_owner': 'Owner', 'search_queue': 'Queue', 'search_requestor': 'Requestor', 'search_status': 'Status', 'search_subject_like': 'Subject__like'}
  attachment_regex: str = '\\.csv\\.zip$'
  extract_attachment: bool = True
  extract_download: bool = True
  http_password: str = None
  http_username: str = None
  init()
  password: str = 'password'
  process()
  rate_limit: int = 3600
  search_not_older_than: str = None
  search_owner: str = 'nobody'
  search_queue: str = 'Incident Reports'
  search_requestor: Optional[str] = None
  search_status: str = 'new'
  search_subject_like: str = 'Report'
  set_status: str = 'open'
  ssl_client_certificate: str = None
  take_ticket: bool = True
  uri: str = 'http://localhost/rt/REST/1.0'
  url_regex: str = 'https://dl.shadowserver.org/[a-zA-Z0-9?_-]*'
  user: str = 'intelmq'

## Module contents